@@ -3,11 +3,13 @@ use std::{
     error::Error,
     fmt::{self, Debug, Display, Formatter},
     ops::Range,
+    path::Path,
 };
 use yggdrasil_shared::records::Url;
 
 mod error_custom;
 mod error_std;
+mod error_3rd;
 
 pub type Result<T> = std::result::Result<T, NoteError>;
 
@@ -26,19 +28,26 @@ pub enum NoteErrorKind {
     RuntimeError(String),
     /// A forbidden cst_node encountered
     Unreachable,
-    /* #[error(transparent)]
-     * UnknownError(#[from] anyhow::Error), */
+    // #[error(transparent)]
+    // UnknownError(#[from] anyhow::Error),
 }
 
 impl NoteError {
-    pub fn set_url(mut self, url: Url) -> Self {
+    #[inline]
+    pub fn set_path(&mut self, path: impl AsRef<Path>) {
+        if let Ok(s) = Url::from_file_path(path) {
+            self.file = Some(s)
+        }
+    }
+    #[inline]
+    pub fn set_url(&mut self, url: Url) {
         self.file = Some(url);
-        return self;
     }
-    pub fn set_range(mut self, start: usize, end: usize) -> Self {
+    #[inline]
+    pub fn set_range(&mut self, start: usize, end: usize) {
         self.range = Some(Range { start, end });
-        return self;
     }
+    #[inline]
     pub fn unreachable() -> Self {
         Self { kind: Box::new(NoteErrorKind::Unreachable), file: None, range: None }
     }
@@ -79,18 +88,19 @@ impl Display for NoteError {
 impl Display for NoteErrorKind {
     fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
         match self {
-            Self::IOError { .. } => {
-                unimplemented!()
+            Self::IOError(e) => {
+                write!(f, "{}", e)
             }
-            Self::FormatError { .. } => {
-                unimplemented!()
+            Self::FormatError(e) => {
+                write!(f, "{}", e)
             }
             Self::TypeMismatch(msg) => {
                 f.write_str("TypeMismatch: ")?;
                 f.write_str(msg)
             }
-            Self::RuntimeError(_) => {
-                unimplemented!()
+            Self::RuntimeError(msg) => {
+                f.write_str("TypeMismatch: ")?;
+                f.write_str(msg)
             }
             Self::Unreachable => {
                 f.write_str("InternalError: ")?;
